@@ -2,10 +2,11 @@
 
 isort:skip_file
 """
-from typing import Sequence, Union
 
 import attr
-import numpy as np  # type: ignore
+import numpy as np
+import numpy.typing as npt
+
 
 from pybotics.geometry import matrix_2_vector, position_from_matrix, vector_2_matrix
 
@@ -14,12 +15,12 @@ from pybotics.geometry import matrix_2_vector, position_from_matrix, vector_2_ma
 class Tool:
     """Tool class."""
 
-    matrix = attr.ib(factory=lambda: np.eye(4), type=np.ndarray)  # type: ignore
+    matrix = attr.ib(factory=lambda: np.eye(4), type=npt.NDArray[np.float64])
     mass = attr.ib(0, type=float)
-    cg = attr.ib(factory=lambda: np.zeros(3), type=np.ndarray)  # type: ignore
+    cg = attr.ib(factory=lambda: np.zeros(3), type=npt.NDArray[np.float64])
 
     @property
-    def position(self) -> Union[Sequence[float], np.ndarray]:
+    def position(self) -> npt.NDArray[np.float64]:
         """
         Get the position XYZ of the frame.
 
@@ -28,11 +29,11 @@ class Tool:
         return position_from_matrix(self.matrix)
 
     @position.setter
-    def position(self, value: Sequence[float]) -> None:
+    def position(self, value: npt.NDArray[np.float64]) -> None:
         self.matrix[:-1, -1] = value
 
     @property
-    def vector(self) -> np.ndarray:
+    def vector(self) -> npt.NDArray[np.float64]:
         """
         Return the vector representation of the frame as EULER ZYX.
 
@@ -41,5 +42,5 @@ class Tool:
         return matrix_2_vector(self.matrix)
 
     @vector.setter
-    def vector(self, value: Sequence[float]) -> None:
+    def vector(self, value: npt.NDArray[np.float64]) -> None:
         self.matrix = vector_2_matrix(value)
